Library for rendering a tree of vectors into a string of HTML. Pre-compiles where possible for performance.
Library for rendering a tree of vectors into a string of HTML. Pre-compiles where possible for performance.
(h text)Escape strings within the html macro.
Escape strings within the [[html]] macro.
(html options & content)Render Clojure data structures to a string of HTML. Strings are not
automatically escaped, but must be manually escaped with the h function.
A literal option map may be specified as the first argument. It accepts the following keys:
:mode
: One of :html, :xhtml, :xml or :sgml (defaults to :xhtml).
Controls how tags are rendered.
Render Clojure data structures to a string of HTML. Strings are **not** automatically escaped, but must be manually escaped with the [[h]] function. A literal option map may be specified as the first argument. It accepts the following keys: `:mode` : One of `:html`, `:xhtml`, `:xml` or `:sgml` (defaults to `:xhtml`). Controls how tags are rendered.
cljdoc builds & hosts documentation for Clojure/Script libraries
| Ctrl+k | Jump to recent docs |
| ← | Move to previous article |
| → | Move to next article |
| Ctrl+/ | Jump to the search field |